@@ -111,7 +111,7 @@ class sentence_tranformer_checker():
             or the column name in the target dataframe.
             target_col (partially optional): the target column name used to match, *must be specified for dataframe matching*.
             device: the device to do the encoding on operations in (cpu|cuda),
-            model (optional): a sentence tranformer model object, to use instead of the default one, for more [details](https://www.sbert.net/).
+            model (optional): a string of the sentence tranformer model, to use instead of the default one, for more [details](https://www.sbert.net/).
             lang (optional): the languge of the model ('en'|'ar').
             only_include (optional): used only for dataframe matching, allow providing a list of column names to only include for the target matches, provide empty list to get only target_col.
             encode_batch (optional): the number of sentences to encode in a batch.
